IntoJoinExt

Trait IntoJoinExt 

pub trait IntoJoinExt: IntoJoin {
    // Provided methods
    fn join(self) -> JoinIter<Self::IntoJoin> 
       where Self: Sized,
             <Self::IntoJoin as Join>::Mask: BitSetConstrained { ... }
    fn join_unconstrained(self) -> JoinIter<Self::IntoJoin> 
       where Self: Sized { ... }
    fn maybe(self) -> MaybeJoin<Self::IntoJoin>
       where Self: Sized { ... }
}

Provided Methods

fn join(self) -> JoinIter<Self::IntoJoin>
where Self: Sized, <Self::IntoJoin as Join>::Mask: BitSetConstrained,

Safely iterate over this Join.

Panics

Panics if the result of this join is unconstrained.

fn join_unconstrained(self) -> JoinIter<Self::IntoJoin>
where Self: Sized,

Safely iterate over this Join, and don’t panic if it is unconstrained.

Constraint detection is not perfect, so this is here if it is in your way.

fn maybe(self) -> MaybeJoin<Self::IntoJoin>
where Self: Sized,

Implementors