pub struct HashMapStorage<T>(/* private fields */);Trait Implementations
Sourceimpl<T> Default for HashMapStorage<T>
impl<T> Default for HashMapStorage<T>
Sourceimpl<T> RawStorage for HashMapStorage<T>
impl<T> RawStorage for HashMapStorage<T>
type Item = T
Sourceunsafe fn get(&self, index: Index) -> &T
unsafe fn get(&self, index: Index) -> &T
Return a reference to the component at the given index. Read more
Sourceunsafe fn get_mut(&self, index: Index) -> &mut T
unsafe fn get_mut(&self, index: Index) -> &mut T
Return a mutable reference to the component at the given index. Read more
impl<T: Send> Send for HashMapStorage<T>
impl<T: Sync> Sync for HashMapStorage<T>