pub struct Entities<'a>(/* private fields */);Implementations
Sourceimpl<'a> Entities<'a>
impl<'a> Entities<'a>
Sourcepub fn delete(&self, e: Entity) -> Result<(), WrongGeneration>
pub fn delete(&self, e: Entity) -> Result<(), WrongGeneration>
Atomically request that this entity be removed on the next call to World::merge_atomic.
An entity is not deleted until World::merge_atomic is called, so it will still be ‘alive’
and show up in queries until that time.
pub fn is_alive(&self, e: Entity) -> bool
pub fn entity(&self, index: Index) -> Option<Entity>
Sourcepub fn create(&self) -> Entity
pub fn create(&self) -> Entity
Atomically allocate an entity. An atomically allocated entity is indistinguishable from a
regular live entity, but when World::merge_atomic is called it will be merged into a
non-atomic BitSet for performance.
pub fn live_bitset(&self) -> LiveBitSet<'_>